camelot.camelot.model.i18n.Translation.Admin

Package camelot :: Package camelot :: Package model :: Module i18n :: Class Translation :: Class Admin |
[hide private]
[frames] | no frames]

# Class Admin

source code

Instance Methods | [hide private]
Inherited from `view.elixir_admin.EntityAdmin`: `__init__`, `__str__`, `createFormView`, `createNewView`, `createSelectView`, `createTableView`, `createValidator`, `getColumns`, `getFieldAttributes`, `getFields`, `getFilters`, `getForm`, `getFormActions`, `getListCharts`, `getModelThread`, `getName`, `getRelatedEntityAdmin`, `getSubclasses`, `setDefaults` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
| section = `'configuration'`
| list_display = `['source', 'language', 'value', 'uid']`
| list_filter = `['language']`
Inherited from `view.elixir_admin.EntityAdmin`: `field_attributes`, `fields`, `form`, `form_actions`, `form_display`, `form_size`, `form_title_column`, `list_actions`, `list_charts`, `list_size`, `name`

Properties | [hide private]
Inherited from `object`: `__class__`